@@ -815,6 +815,15 @@ func TestRequireAndDynamicImportInvalidTemplate(t *testing.T) {
 				require(` + "`./${b}`" + `)
 				import(tag` + "`./b`" + `)
 				import(` + "`./${b}`" + `)
+
+				// Try/catch should silence this warning for require()
+				try {
+					require(tag` + "`./b`" + `)
+					require(` + "`./${b}`" + `)
+					import(tag` + "`./b`" + `)
+					import(` + "`./${b}`" + `)
+				} catch {
+				}
 			`,
 		},
 		entryPaths: []string{"/entry.js"},
@@ -826,6 +835,8 @@ func TestRequireAndDynamicImportInvalidTemplate(t *testing.T) {
 /entry.js: warning: This call to "require" will not be bundled because the argument is not a string literal
 /entry.js: warning: This dynamic import will not be bundled because the argument is not a string literal
 /entry.js: warning: This dynamic import will not be bundled because the argument is not a string literal
+/entry.js: warning: This dynamic import will not be bundled because the argument is not a string literal
+/entry.js: warning: This dynamic import will not be bundled because the argument is not a string literal
 `,
 	})
 }
@@ -836,6 +847,13 @@ func TestRequireBadArgumentCount(t *testing.T) {
 			"/entry.js": `
 				require()
 				require("a", "b")
+
+				// Try/catch should silence this warning
+				try {
+					require()
+					require("a", "b")
+				} catch {
+				}
 			`,
 		},
 		entryPaths: []string{"/entry.js"},
@@ -2716,6 +2734,11 @@ func TestAssignToImport(t *testing.T) {
 				import "./bad8.js"
 				import "./bad9.js"
 				import "./bad10.js"
+				import "./bad11.js"
+				import "./bad12.js"
+				import "./bad13.js"
+				import "./bad14.js"
+				import "./bad15.js"
 
 				import "./good0.js"
 				import "./good1.js"
@@ -2736,6 +2759,11 @@ func TestAssignToImport(t *testing.T) {
 			"/bad8.js":  `import * as x from "foo"; x[y] = 1`,
 			"/bad9.js":  `import * as x from "foo"; x['y'] = 1`,
 			"/bad10.js": `import * as x from "foo"; x['y z'] = 1`,
+			"/bad11.js": `import x from "foo"; delete x`,
+			"/bad12.js": `import {x} from "foo"; delete x`,
+			"/bad13.js": `import * as x from "foo"; delete x.y`,
+			"/bad14.js": `import * as x from "foo"; delete x['y']`,
+			"/bad15.js": `import * as x from "foo"; delete x[y]`,
 
 			"/good0.js": `import x from "foo"; ({y = x} = 1)`,
 			"/good1.js": `import x from "foo"; ({[x]: y} = 1)`,
@@ -2752,6 +2780,11 @@ func TestAssignToImport(t *testing.T) {
 		expectedScanLog: `/bad0.js: error: Cannot assign to import "x"
 /bad1.js: error: Cannot assign to import "x"
 /bad10.js: error: Cannot assign to import "y z"
+/bad11.js: error: Cannot assign to import "x"
+/bad12.js: error: Cannot assign to import "x"
+/bad13.js: error: Cannot assign to import "y"
+/bad14.js: error: Cannot assign to import "y"
+/bad15.js: error: Cannot assign to property on import "x"
 /bad2.js: error: Cannot assign to import "x"
 /bad3.js: error: Cannot assign to import "x"
 /bad4.js: error: Cannot assign to import "x"
@@ -2883,6 +2916,11 @@ func TestRequireResolve(t *testing.T) {
 				if (false) {
 					console.log(require.resolve('dead-code'))
 				}
+				console.log(false ? require.resolve('dead-if') : 0)
+				console.log(true ? 0 : require.resolve('dead-if'))
+				console.log(false && require.resolve('dead-and'))
+				console.log(true || require.resolve('dead-or'))
+				console.log(true ?? require.resolve('dead-nullish'))
 			`,
 			"/present-file.js": ``,
 		},
@@ -3285,3 +3323,34 @@ func TestProcessEnvNodeEnvWarningNoBundle(t *testing.T) {
 		},
 	})
 }
+
+func TestKeepNamesTreeShaking(t *testing.T) {
+	default_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/entry.js": `
+				function fnStmtRemove() {}
+				function fnStmtKeep() {}
+				fnStmtKeep()
+
+				let fnExprRemove = function remove() {}
+				let fnExprKeep = function keep() {}
+				fnExprKeep()
+
+				class clsStmtRemove {}
+				class clsStmtKeep {}
+				new clsStmtKeep()
+
+				let clsExprRemove = class remove {}
+				let clsExprKeep = class keep {}
+				new clsExprKeep()
+			`,
+		},
+		entryPaths: []string{"/entry.js"},
+		options: config.Options{
+			Mode:          config.ModeBundle,
+			AbsOutputFile: "/out.js",
+			KeepNames:     true,
+			MangleSyntax:  true,
+		},
+	})
+}
