@@ -176,6 +176,7 @@ type Options struct {
 	UseDefineForClassFields bool
 	AvoidTDZ                bool
 	ASCIIOnly               bool
+	KeepNames               bool
 
 	Defines  *ProcessedDefines
 	TS       TSOptions
@@ -268,7 +269,7 @@ func CompileFilterForPlugin(pluginName string, kind string, filter string) (*reg
 
 	result := compileFilter(filter)
 	if result == nil {
-		return nil, fmt.Errorf("[%s] %q filter is not a valid regular expression: %q", pluginName, kind, filter)
+		return nil, fmt.Errorf("[%s] %q filter is not a valid Go regular expression: %q", pluginName, kind, filter)
 	}
 
 	return result, nil
@@ -303,9 +304,8 @@ type OnResolveArgs struct {
 type OnResolveResult struct {
 	PluginName string
 
-	Path      logger.Path
-	External  bool
-	Namespace string
+	Path     logger.Path
+	External bool
 
 	Msgs        []logger.Msg
 	ThrownError error
