@@ -653,7 +653,7 @@ func Assign(a Expr, b Expr) Expr {
 }
 
 func AssignStmt(a Expr, b Expr) Stmt {
-	return Stmt{a.Loc, &SExpr{Expr{a.Loc, &EBinary{BinOpAssign, a, b}}}}
+	return Stmt{a.Loc, &SExpr{Value: Assign(a, b)}}
 }
 
 func Not(a Expr) Expr {
@@ -748,8 +748,12 @@ type SExportDefault struct {
 }
 
 type ExportStarAlias struct {
-	Loc  logger.Loc
-	Name string
+	Loc logger.Loc
+
+	// Although this alias name starts off as being the same as the statement's
+	// namespace symbol, it may diverge if the namespace symbol name is minified.
+	// The original alias name is preserved here to avoid this scenario.
+	OriginalName string
 }
 
 type SExportStar struct {
@@ -771,6 +775,11 @@ type SLazyExport struct {
 
 type SExpr struct {
 	Value Expr
+
+	// This is set to true for automatically-generated expressions that should
+	// not affect tree shaking. For example, calling a function from the runtime
+	// that doesn't have externally-visible side effects.
+	DoesNotAffectTreeShaking bool
 }
 
 type EnumValue struct {
@@ -927,8 +936,8 @@ type SLocal struct {
 	IsExport bool
 
 	// The TypeScript compiler doesn't generate code for "import foo = bar"
-	// statements inside namespaces where the import is never used.
-	WasTSImportEqualsInNamespace bool
+	// statements where the import is never used.
+	WasTSImportEquals bool
 }
 
 type SBreak struct {
@@ -989,9 +998,14 @@ type ClauseItem struct {
 	AliasLoc logger.Loc
 	Name     LocRef
 
-	// This is needed for "export {foo as bar} from 'path'" statements. This case
-	// is a re-export and "foo" and "bar" are both aliases. We need to preserve
-	// both aliases in case the symbol is renamed.
+	// This is the original name of the symbol stored in "Name". It's needed for
+	// "SExportClause" statements such as this:
+	//
+	//   export {foo as bar} from 'path'
+	//
+	// In this case both "foo" and "bar" are aliases because it's a re-export.
+	// We need to preserve both aliases in case the symbol is renamed. In this
+	// example, "foo" is "OriginalName" and "bar" is "Alias".
 	OriginalName string
 }
 
@@ -1466,7 +1480,7 @@ func (minifier *NameMinifier) NumberToMinifiedName(i int) string {
 }
 
 func (ast *AST) HasCommonJSFeatures() bool {
-	return ast.HasTopLevelReturn || ast.UsesExportsRef || ast.UsesModuleRef
+	return ast.UsesCommonJSExports() || ast.HasTopLevelReturn
 }
 
 func (ast *AST) UsesCommonJSExports() bool {
