@@ -811,9 +811,6 @@ func (p *parser) parseTypeScriptEnumStmt(loc logger.Loc, opts parseStmtOpts) js_
 
 	if !opts.isTypeScriptDeclare {
 		p.popScope()
-		if opts.isExport {
-			p.recordExport(nameLoc, nameText, name.Ref)
-		}
 	}
 
 	p.lexer.Expect(js_lexer.TCloseBrace)
@@ -825,6 +822,55 @@ func (p *parser) parseTypeScriptEnumStmt(loc logger.Loc, opts parseStmtOpts) js_
 	}}
 }
 
+// This assumes the caller has already parsed the "import" token
+func (p *parser) parseTypeScriptImportEqualsStmt(loc logger.Loc, opts parseStmtOpts, defaultNameLoc logger.Loc, defaultName string) js_ast.Stmt {
+	p.lexer.Expect(js_lexer.TEquals)
+
+	kind := js_ast.LocalVar
+	name := p.lexer.Identifier
+	value := js_ast.Expr{Loc: p.lexer.Loc(), Data: &js_ast.EIdentifier{Ref: p.storeNameInRef(name)}}
+	p.lexer.Expect(js_lexer.TIdentifier)
+
+	if name == "require" && p.lexer.Token == js_lexer.TOpenParen {
+		// "import ns = require('x')"
+		p.lexer.Next()
+		path := js_ast.Expr{Loc: p.lexer.Loc(), Data: &js_ast.EString{Value: p.lexer.StringLiteral}}
+		p.lexer.Expect(js_lexer.TStringLiteral)
+		p.lexer.Expect(js_lexer.TCloseParen)
+		kind = js_ast.LocalConst
+		value.Data = &js_ast.ECall{
+			Target: value,
+			Args:   []js_ast.Expr{path},
+		}
+	} else {
+		// "import Foo = Bar"
+		// "import Foo = Bar.Baz"
+		for p.lexer.Token == js_lexer.TDot {
+			p.lexer.Next()
+			value.Data = &js_ast.EDot{
+				Target:  value,
+				Name:    p.lexer.Identifier,
+				NameLoc: p.lexer.Loc(),
+			}
+			p.lexer.Expect(js_lexer.TIdentifier)
+		}
+	}
+
+	p.lexer.ExpectOrInsertSemicolon()
+	ref := p.declareSymbol(js_ast.SymbolOther, defaultNameLoc, defaultName)
+	decls := []js_ast.Decl{{
+		Binding: js_ast.Binding{Loc: defaultNameLoc, Data: &js_ast.BIdentifier{Ref: ref}},
+		Value:   &value,
+	}}
+
+	return js_ast.Stmt{Loc: loc, Data: &js_ast.SLocal{
+		Kind:              kind,
+		Decls:             decls,
+		IsExport:          opts.isExport,
+		WasTSImportEquals: true,
+	}}
+}
+
 func (p *parser) parseTypeScriptNamespaceStmt(loc logger.Loc, opts parseStmtOpts) js_ast.Stmt {
 	// "namespace Foo {}"
 	nameLoc := p.lexer.Loc()
@@ -832,10 +878,7 @@ func (p *parser) parseTypeScriptNamespaceStmt(loc logger.Loc, opts parseStmtOpts
 	p.lexer.Next()
 
 	name := js_ast.LocRef{Loc: nameLoc, Ref: js_ast.InvalidRef}
-
 	scopeIndex := p.pushScopeForParsePass(js_ast.ScopeEntry, loc)
-	oldEnclosingNamespaceRef := p.enclosingNamespaceRef
-	p.enclosingNamespaceRef = &name.Ref
 
 	var stmts []js_ast.Stmt
 	if p.lexer.Token == js_lexer.TDot {
@@ -857,15 +900,13 @@ func (p *parser) parseTypeScriptNamespaceStmt(loc logger.Loc, opts parseStmtOpts
 		p.lexer.Next()
 	}
 
-	p.enclosingNamespaceRef = oldEnclosingNamespaceRef
-
 	// Import assignments may be only used in type expressions, not value
 	// expressions. If this is the case, the TypeScript compiler removes
 	// them entirely from the output. That can cause the namespace itself
 	// to be considered empty and thus be removed.
 	importEqualsCount := 0
 	for _, stmt := range stmts {
-		if local, ok := stmt.Data.(*js_ast.SLocal); ok && local.WasTSImportEqualsInNamespace && !local.IsExport {
+		if local, ok := stmt.Data.(*js_ast.SLocal); ok && local.WasTSImportEquals && !local.IsExport {
 			importEqualsCount++
 		}
 	}
@@ -914,16 +955,7 @@ func (p *parser) parseTypeScriptNamespaceStmt(loc logger.Loc, opts parseStmtOpts
 
 	p.popScope()
 	if !opts.isTypeScriptDeclare {
-		_, alreadyExists := p.currentScope.Members[nameText]
 		name.Ref = p.declareSymbol(js_ast.SymbolTSNamespace, nameLoc, nameText)
-
-		// It's valid to have multiple exported namespace statements as long as
-		// each one has the "export" keyword. Make sure we don't record the same
-		// export more than once, because then we will incorrectly detect duplicate
-		// exports.
-		if opts.isExport && !alreadyExists {
-			p.recordExport(nameLoc, nameText, name.Ref)
-		}
 	}
 	return js_ast.Stmt{Loc: loc, Data: &js_ast.SNamespace{
 		Name:     name,
@@ -948,7 +980,7 @@ func (p *parser) generateClosureForTypeScriptNamespaceOrEnum(
 	// can be multiple namespace blocks for the same namespace
 	if (symbol.Kind == js_ast.SymbolTSNamespace || symbol.Kind == js_ast.SymbolTSEnum) && !p.emittedNamespaceVars[nameRef] {
 		p.emittedNamespaceVars[nameRef] = true
-		if p.enclosingNamespaceRef == nil {
+		if p.enclosingNamespaceArgRef == nil {
 			// Top-level namespace
 			stmts = append(stmts, js_ast.Stmt{Loc: stmtLoc, Data: &js_ast.SLocal{
 				Kind:     js_ast.LocalVar,
@@ -965,7 +997,7 @@ func (p *parser) generateClosureForTypeScriptNamespaceOrEnum(
 	}
 
 	var argExpr js_ast.Expr
-	if isExport && p.enclosingNamespaceRef != nil {
+	if isExport && p.enclosingNamespaceArgRef != nil {
 		// "name = enclosing.name || (enclosing.name = {})"
 		name := p.symbols[nameRef.InnerIndex].OriginalName
 		argExpr = js_ast.Assign(
@@ -973,13 +1005,13 @@ func (p *parser) generateClosureForTypeScriptNamespaceOrEnum(
 			js_ast.Expr{Loc: nameLoc, Data: &js_ast.EBinary{
 				Op: js_ast.BinOpLogicalOr,
 				Left: js_ast.Expr{Loc: nameLoc, Data: &js_ast.EDot{
-					Target:  js_ast.Expr{Loc: nameLoc, Data: &js_ast.EIdentifier{Ref: *p.enclosingNamespaceRef}},
+					Target:  js_ast.Expr{Loc: nameLoc, Data: &js_ast.EIdentifier{Ref: *p.enclosingNamespaceArgRef}},
 					Name:    name,
 					NameLoc: nameLoc,
 				}},
 				Right: js_ast.Assign(
 					js_ast.Expr{Loc: nameLoc, Data: &js_ast.EDot{
-						Target:  js_ast.Expr{Loc: nameLoc, Data: &js_ast.EIdentifier{Ref: *p.enclosingNamespaceRef}},
+						Target:  js_ast.Expr{Loc: nameLoc, Data: &js_ast.EIdentifier{Ref: *p.enclosingNamespaceArgRef}},
 						Name:    name,
 						NameLoc: nameLoc,
 					}},
@@ -987,8 +1019,8 @@ func (p *parser) generateClosureForTypeScriptNamespaceOrEnum(
 				),
 			}},
 		)
-		p.recordUsage(*p.enclosingNamespaceRef)
-		p.recordUsage(*p.enclosingNamespaceRef)
+		p.recordUsage(*p.enclosingNamespaceArgRef)
+		p.recordUsage(*p.enclosingNamespaceArgRef)
 		p.recordUsage(nameRef)
 	} else {
 		// "name || (name = {})"
