@@ -88,6 +88,7 @@ function pushCommonFlags(flags: string[], options: CommonOptions, keys: OptionKe
   let define = getFlag(options, keys, 'define', mustBeObject);
   let pure = getFlag(options, keys, 'pure', mustBeArray);
   let avoidTDZ = getFlag(options, keys, 'avoidTDZ', mustBeBoolean);
+  let keepNames = getFlag(options, keys, 'keepNames', mustBeBoolean);
 
   if (target) {
     if (Array.isArray(target)) flags.push(`--target=${Array.from(target).map(validateTarget).join(',')}`)
@@ -112,6 +113,7 @@ function pushCommonFlags(flags: string[], options: CommonOptions, keys: OptionKe
   }
   if (pure) for (let fn of pure) flags.push(`--pure:${fn}`);
   if (avoidTDZ) flags.push(`--avoid-tdz`);
+  if (keepNames) flags.push(`--keep-names`);
 }
 
 function flagsForBuildOptions(options: types.BuildOptions, isTTY: boolean, logLevelDefault: types.LogLevel):
@@ -531,7 +533,7 @@ export function createChannel(streamIn: StreamIn): StreamOut {
             let warnings = response!.warnings;
             if (errors.length > 0) return callback(failureErrorWithLog('Build failed', errors, warnings), null);
             let result: types.BuildResult = { warnings };
-            if (!write) result.outputFiles = response!.outputFiles;
+            if (!write) result.outputFiles = response!.outputFiles.map(convertOutputFiles);
             callback(null, result);
           });
         } catch (e) {
@@ -733,3 +735,15 @@ function sanitizeMessages(messages: types.PartialMessage[]): types.Message[] {
 
   return messagesClone;
 }
+
+function convertOutputFiles({ path, contents }: protocol.BuildOutputFile): types.OutputFile {
+  let text: string | null = null;
+  return {
+    path,
+    contents,
+    get text() {
+      if (text === null) text = protocol.decodeUTF8(contents);
+      return text;
+    },
+  }
+}
