@@ -21,6 +21,7 @@ interface CommonOptions {
   define?: { [key: string]: string };
   pure?: string[];
   avoidTDZ?: boolean;
+  keepNames?: boolean;
 
   color?: boolean;
   logLevel?: LogLevel;
@@ -73,7 +74,8 @@ export interface Location {
 
 export interface OutputFile {
   path: string;
-  contents: Uint8Array;
+  contents: Uint8Array; // "text" as bytes
+  text: string; // "contents" as text
 }
 
 export interface BuildResult {
