@@ -49,6 +49,40 @@ let pluginTests = {
     assert.strictEqual(result.default, 123)
   },
 
+  async invalidRegExp({ esbuild }) {
+    for (const filter of [/x(?=y)/, /x(?!y)/, /x(?<=y)/, /x(?<!y)/, /(x)\1/]) {
+      // onResolve
+      try {
+        await esbuild.build({
+          entryPoints: ['invalid.js'], write: false, plugins: [{
+            name: 'name',
+            setup(build) {
+              build.onResolve({ filter }, () => { })
+            },
+          }],
+        })
+        throw new Error(`Expected filter ${filter} to fail`)
+      } catch (e) {
+        assert.strictEqual(e.message, `[name] "onResolve" filter is not a valid Go regular expression: ${JSON.stringify(filter.source)}`)
+      }
+
+      // onLoad
+      try {
+        await esbuild.build({
+          entryPoints: ['invalid.js'], write: false, plugins: [{
+            name: 'name',
+            setup(build) {
+              build.onLoad({ filter }, () => { })
+            },
+          }],
+        })
+        throw new Error(`Expected filter ${filter} to fail`)
+      } catch (e) {
+        assert.strictEqual(e.message, `[name] "onLoad" filter is not a valid Go regular expression: ${JSON.stringify(filter.source)}`)
+      }
+    }
+  },
+
   async basicLoader({ esbuild, testDir }) {
     const input = path.join(testDir, 'in.js')
     const custom = path.join(testDir, 'example.custom')
@@ -289,7 +323,7 @@ let pluginTests = {
     assert.strictEqual(result.default, 123)
   },
 
-  async rewriteExternal({ esbuild, testDir }) {
+  async rewriteExternalWithNamespace({ esbuild, testDir }) {
     const input = path.join(testDir, 'in.js')
     const output = path.join(testDir, 'out.js')
     await writeFileAsync(input, `
@@ -310,6 +344,58 @@ let pluginTests = {
     assert.strictEqual(result.default, fs.exists)
   },
 
+  async rewriteExternalWithoutNamespace({ esbuild, testDir }) {
+    const input = path.join(testDir, 'in.js')
+    const output = path.join(testDir, 'out.js')
+    await writeFileAsync(input, `
+      import {exists} from 'extern'
+      export default exists
+    `)
+    await esbuild.build({
+      entryPoints: [input], bundle: true, outfile: output, format: 'cjs', plugins: [{
+        name: 'name',
+        setup(build) {
+          build.onResolve({ filter: /^extern$/ }, () => {
+            return { path: 'fs', external: true }
+          })
+        },
+      }],
+    })
+    const result = require(output)
+    assert.strictEqual(result.default, fs.exists)
+  },
+
+  async rewriteExternalWithFileNamespace({ esbuild, testDir }) {
+    const input = path.join(testDir, 'in.js')
+    const outdir = path.join(testDir, 'out')
+    const outdir2 = path.join(testDir, 'out2')
+    const target = path.join(outdir2, 'target.js')
+    await writeFileAsync(input, `
+      import {exists} from 'extern'
+      export default exists
+    `)
+    await mkdirAsync(outdir2, { recursive: true })
+    await writeFileAsync(target, `
+      module.exports = require('fs')
+    `)
+    await esbuild.build({
+      entryPoints: [input], bundle: true, outdir, format: 'cjs', plugins: [{
+        name: 'name',
+        setup(build) {
+          build.onResolve({ filter: /^extern$/ }, () => {
+            return { path: path.join(outdir, 'target'), external: true, namespace: 'file' }
+          })
+        },
+      }],
+    })
+
+    // Move the file to show that the output has a relative path
+    await fs.promises.rename(path.join(outdir, 'in.js'), path.join(outdir2, 'in.js'))
+
+    const result = require(path.join(outdir2, 'in.js'))
+    assert.strictEqual(result.default, fs.exists)
+  },
+
   async resolveDirInFileModule({ esbuild, testDir }) {
     const input = path.join(testDir, 'in.js')
     const output = path.join(testDir, 'out.js')
